# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentArgs', 'Deployment']

@pulumi.input_type
class DeploymentArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 gateway_id: pulumi.Input[str],
                 path_prefix: pulumi.Input[str],
                 specification: pulumi.Input['DeploymentSpecificationArgs'],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a Deployment resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        :param pulumi.Input[str] gateway_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        :param pulumi.Input[str] path_prefix: A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        :param pulumi.Input['DeploymentSpecificationArgs'] specification: (Updatable) The logical configuration of the API exposed by a deployment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "path_prefix", path_prefix)
        pulumi.set(__self__, "specification", specification)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> pulumi.Input[str]:
        """
        A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        """
        return pulumi.get(self, "path_prefix")

    @path_prefix.setter
    def path_prefix(self, value: pulumi.Input[str]):
        pulumi.set(self, "path_prefix", value)

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Input['DeploymentSpecificationArgs']:
        """
        (Updatable) The logical configuration of the API exposed by a deployment.
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: pulumi.Input['DeploymentSpecificationArgs']):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)


@pulumi.input_type
class _DeploymentState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 gateway_id: Optional[pulumi.Input[str]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input['DeploymentSpecificationArgs']] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Deployment resources.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        :param pulumi.Input[str] endpoint: The endpoint to access this deployment on the gateway.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] gateway_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
        :param pulumi.Input[str] path_prefix: A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        :param pulumi.Input['DeploymentSpecificationArgs'] specification: (Updatable) The logical configuration of the API exposed by a deployment.
        :param pulumi.Input[str] state: The current state of the deployment.
        :param pulumi.Input[str] time_created: The time this resource was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time this resource was last updated. An RFC3339 formatted datetime string.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if path_prefix is not None:
            pulumi.set(__self__, "path_prefix", path_prefix)
        if specification is not None:
            pulumi.set(__self__, "specification", specification)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint to access this deployment on the gateway.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        """
        return pulumi.get(self, "path_prefix")

    @path_prefix.setter
    def path_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path_prefix", value)

    @property
    @pulumi.getter
    def specification(self) -> Optional[pulumi.Input['DeploymentSpecificationArgs']]:
        """
        (Updatable) The logical configuration of the API exposed by a deployment.
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: Optional[pulumi.Input['DeploymentSpecificationArgs']]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the deployment.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time this resource was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time this resource was last updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class Deployment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 gateway_id: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[pulumi.InputType['DeploymentSpecificationArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Deployment resource in Oracle Cloud Infrastructure API Gateway service.

        Creates a new deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_deployment = oci.api_gateway.Deployment("testDeployment",
            compartment_id=var["compartment_id"],
            gateway_id=oci_apigateway_gateway["test_gateway"]["id"],
            path_prefix=var["deployment_path_prefix"],
            specification=oci.api_gateway.DeploymentSpecificationArgs(
                logging_policies=oci.api_gateway.DeploymentSpecificationLoggingPoliciesArgs(
                    access_log=oci.api_gateway.DeploymentSpecificationLoggingPoliciesAccessLogArgs(
                        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    execution_log=oci.api_gateway.DeploymentSpecificationLoggingPoliciesExecutionLogArgs(
                        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        log_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                request_policies=oci.api_gateway.DeploymentSpecificationRequestPoliciesArgs(
                    authentication=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        cache_keys=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_anonymous_access_allowed=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        max_clock_skew_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        parameters=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        public_keys=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationPublicKeysArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationPublicKeysKeyArgs(
                                format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        token_auth_scheme=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        token_header=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        token_query_param=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        validation_failure_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyClientDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            fallback_redirect_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            logout_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_expiry_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_code=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_header_transformations=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsArgs(
                                filter_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsFilterHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsFilterHeadersItemArgs(
                                        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                rename_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsRenameHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsRenameHeadersItemArgs(
                                        from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                ),
                                set_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsSetHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsSetHeadersItemArgs(
                                        if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                ),
                            ),
                            response_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicySourceUriDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            use_cookies_for_intermediate_steps=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            use_cookies_for_session=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            use_pkce=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            additional_validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyAdditionalValidationPolicyArgs(
                                audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyAdditionalValidationPolicyVerifyClaimArgs(
                                    is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyClientDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyKeyArgs(
                                format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicySourceUriDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationVerifyClaimArgs(
                            is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                    ),
                    cors=oci.api_gateway.DeploymentSpecificationRequestPoliciesCorsArgs(
                        allowed_origins=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        exposed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_allow_credentials_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        max_age_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    dynamic_authentication=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationArgs(
                        authentication_servers=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerArgs(
                            authentication_server_detail=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_anonymous_access_allowed=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                max_clock_skew_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                public_keys=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailPublicKeysArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailPublicKeysKeyArgs(
                                        format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                token_auth_scheme=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                token_header=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                token_query_param=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                validation_failure_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyClientDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    fallback_redirect_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    logout_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    max_expiry_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_code=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_header_transformations=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsArgs(
                                        filter_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsFilterHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsFilterHeadersItemArgs(
                                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        ),
                                        rename_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsRenameHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsRenameHeadersItemArgs(
                                                from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                        ),
                                        set_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsSetHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsSetHeadersItemArgs(
                                                if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                        ),
                                    ),
                                    response_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicySourceUriDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    use_cookies_for_intermediate_steps=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    use_cookies_for_session=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    use_pkce=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    additional_validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyAdditionalValidationPolicyArgs(
                                        audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyAdditionalValidationPolicyVerifyClaimArgs(
                                            is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        )],
                                    ),
                                    client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyClientDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyKeyArgs(
                                        format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicySourceUriDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailVerifyClaimArgs(
                                    is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            key=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerKeyArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_default=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                        )],
                        selection_source=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationSelectionSourceArgs(
                            selector=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    mutual_tls=oci.api_gateway.DeploymentSpecificationRequestPoliciesMutualTlsArgs(
                        allowed_sans=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_verified_certificate_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    rate_limiting=oci.api_gateway.DeploymentSpecificationRequestPoliciesRateLimitingArgs(
                        rate_in_requests_per_second=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        rate_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    usage_plans=oci.api_gateway.DeploymentSpecificationRequestPoliciesUsagePlansArgs(
                        token_locations=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                routes=[oci.api_gateway.DeploymentSpecificationRouteArgs(
                    backend=oci.api_gateway.DeploymentSpecificationRouteBackendArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_post_logout_uris=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        body=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        connect_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        headers=[oci.api_gateway.DeploymentSpecificationRouteBackendHeaderArgs(
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        post_logout_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        read_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        routing_backends=[oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendArgs(
                            backend=oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendBackendArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                body=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                connect_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                headers=[oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendBackendHeaderArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                read_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                send_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            key=oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendKeyArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_default=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                        )],
                        selection_source=oci.api_gateway.DeploymentSpecificationRouteBackendSelectionSourceArgs(
                            selector=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        send_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    logging_policies=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesArgs(
                        access_log=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesAccessLogArgs(
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        execution_log=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesExecutionLogArgs(
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            log_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    request_policies=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesArgs(
                        authorization=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesAuthorizationArgs(
                            allowed_scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        body_validation=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesBodyValidationArgs(
                            contents=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesBodyValidationContentArgs(
                                media_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                validation_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        cors=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesCorsArgs(
                            allowed_origins=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            allowed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            allowed_methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            exposed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_allow_credentials_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_age_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        header_transformations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsArgs(
                            filter_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsFilterHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsFilterHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsRenameHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsRenameHeadersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsSetHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsSetHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        header_validations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderValidationsArgs(
                            headers=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderValidationsHeaderArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        query_parameter_transformations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsArgs(
                            filter_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsFilterQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsFilterQueryParametersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsRenameQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsRenameQueryParametersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsSetQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsSetQueryParametersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        query_parameter_validations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterValidationsArgs(
                            parameters=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterValidationsParameterArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        response_cache_lookup=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesResponseCacheLookupArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            cache_key_additions=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_private_caching_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    response_policies=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesArgs(
                        header_transformations=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsArgs(
                            filter_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsFilterHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsFilterHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsRenameHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsRenameHeadersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsSetHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsSetHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        response_cache_store=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesResponseCacheStoreArgs(
                            time_to_live_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                )],
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["deployment_display_name"],
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        Deployments can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:ApiGateway/deployment:Deployment test_deployment "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] gateway_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        :param pulumi.Input[str] path_prefix: A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        :param pulumi.Input[pulumi.InputType['DeploymentSpecificationArgs']] specification: (Updatable) The logical configuration of the API exposed by a deployment.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Deployment resource in Oracle Cloud Infrastructure API Gateway service.

        Creates a new deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_deployment = oci.api_gateway.Deployment("testDeployment",
            compartment_id=var["compartment_id"],
            gateway_id=oci_apigateway_gateway["test_gateway"]["id"],
            path_prefix=var["deployment_path_prefix"],
            specification=oci.api_gateway.DeploymentSpecificationArgs(
                logging_policies=oci.api_gateway.DeploymentSpecificationLoggingPoliciesArgs(
                    access_log=oci.api_gateway.DeploymentSpecificationLoggingPoliciesAccessLogArgs(
                        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    execution_log=oci.api_gateway.DeploymentSpecificationLoggingPoliciesExecutionLogArgs(
                        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        log_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                request_policies=oci.api_gateway.DeploymentSpecificationRequestPoliciesArgs(
                    authentication=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        cache_keys=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_anonymous_access_allowed=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        max_clock_skew_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        parameters=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        public_keys=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationPublicKeysArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationPublicKeysKeyArgs(
                                format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        token_auth_scheme=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        token_header=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        token_query_param=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        validation_failure_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyClientDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            fallback_redirect_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            logout_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_expiry_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_code=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_header_transformations=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsArgs(
                                filter_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsFilterHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsFilterHeadersItemArgs(
                                        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                rename_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsRenameHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsRenameHeadersItemArgs(
                                        from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                ),
                                set_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsSetHeadersArgs(
                                    items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicyResponseHeaderTransformationsSetHeadersItemArgs(
                                        if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                ),
                            ),
                            response_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            response_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationFailurePolicySourceUriDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            use_cookies_for_intermediate_steps=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            use_cookies_for_session=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            use_pkce=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            additional_validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyAdditionalValidationPolicyArgs(
                                audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyAdditionalValidationPolicyVerifyClaimArgs(
                                    is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyClientDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicyKeyArgs(
                                format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationValidationPolicySourceUriDetailsArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesAuthenticationVerifyClaimArgs(
                            is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                    ),
                    cors=oci.api_gateway.DeploymentSpecificationRequestPoliciesCorsArgs(
                        allowed_origins=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        exposed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_allow_credentials_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        max_age_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    dynamic_authentication=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationArgs(
                        authentication_servers=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerArgs(
                            authentication_server_detail=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_anonymous_access_allowed=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                max_clock_skew_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                public_keys=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailPublicKeysArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailPublicKeysKeyArgs(
                                        format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                token_auth_scheme=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                token_header=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                token_query_param=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                validation_failure_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyClientDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    fallback_redirect_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    logout_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    max_expiry_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_code=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_header_transformations=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsArgs(
                                        filter_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsFilterHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsFilterHeadersItemArgs(
                                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        ),
                                        rename_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsRenameHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsRenameHeadersItemArgs(
                                                from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                        ),
                                        set_headers=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsSetHeadersArgs(
                                            items=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicyResponseHeaderTransformationsSetHeadersItemArgs(
                                                if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            )],
                                        ),
                                    ),
                                    response_message=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    response_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationFailurePolicySourceUriDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    use_cookies_for_intermediate_steps=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    use_cookies_for_session=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    use_pkce=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyArgs(
                                    type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    additional_validation_policy=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyAdditionalValidationPolicyArgs(
                                        audiences=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        issuers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyAdditionalValidationPolicyVerifyClaimArgs(
                                            is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                            values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        )],
                                    ),
                                    client_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyClientDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        client_secret_version_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    keys=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicyKeyArgs(
                                        format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        alg=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        e=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        key_ops=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        kty=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        n=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        use=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    )],
                                    max_cache_duration_in_hours=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    source_uri_details=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailValidationPolicySourceUriDetailsArgs(
                                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                        uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    ),
                                    uri=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                ),
                                verify_claims=[oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerAuthenticationServerDetailVerifyClaimArgs(
                                    is_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            key=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationAuthenticationServerKeyArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_default=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                        )],
                        selection_source=oci.api_gateway.DeploymentSpecificationRequestPoliciesDynamicAuthenticationSelectionSourceArgs(
                            selector=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    mutual_tls=oci.api_gateway.DeploymentSpecificationRequestPoliciesMutualTlsArgs(
                        allowed_sans=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_verified_certificate_required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    rate_limiting=oci.api_gateway.DeploymentSpecificationRequestPoliciesRateLimitingArgs(
                        rate_in_requests_per_second=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        rate_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    usage_plans=oci.api_gateway.DeploymentSpecificationRequestPoliciesUsagePlansArgs(
                        token_locations=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                routes=[oci.api_gateway.DeploymentSpecificationRouteArgs(
                    backend=oci.api_gateway.DeploymentSpecificationRouteBackendArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        allowed_post_logout_uris=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        body=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        connect_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        headers=[oci.api_gateway.DeploymentSpecificationRouteBackendHeaderArgs(
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        post_logout_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        read_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        routing_backends=[oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendArgs(
                            backend=oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendBackendArgs(
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                body=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                connect_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                function_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                headers=[oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendBackendHeaderArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                is_ssl_verify_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                read_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                send_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            key=oci.api_gateway.DeploymentSpecificationRouteBackendRoutingBackendKeyArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                is_default=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                        )],
                        selection_source=oci.api_gateway.DeploymentSpecificationRouteBackendSelectionSourceArgs(
                            selector=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        send_timeout_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    logging_policies=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesArgs(
                        access_log=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesAccessLogArgs(
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        execution_log=oci.api_gateway.DeploymentSpecificationRouteLoggingPoliciesExecutionLogArgs(
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            log_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    request_policies=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesArgs(
                        authorization=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesAuthorizationArgs(
                            allowed_scopes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        body_validation=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesBodyValidationArgs(
                            contents=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesBodyValidationContentArgs(
                                media_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                validation_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        cors=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesCorsArgs(
                            allowed_origins=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            allowed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            allowed_methods=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            exposed_headers=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_allow_credentials_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_age_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        header_transformations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsArgs(
                            filter_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsFilterHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsFilterHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsRenameHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsRenameHeadersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_headers=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsSetHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderTransformationsSetHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        header_validations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderValidationsArgs(
                            headers=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesHeaderValidationsHeaderArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        query_parameter_transformations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsArgs(
                            filter_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsFilterQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsFilterQueryParametersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsRenameQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsRenameQueryParametersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_query_parameters=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsSetQueryParametersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterTransformationsSetQueryParametersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        query_parameter_validations=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterValidationsArgs(
                            parameters=[oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesQueryParameterValidationsParameterArgs(
                                name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                required=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            )],
                            validation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        response_cache_lookup=oci.api_gateway.DeploymentSpecificationRouteRequestPoliciesResponseCacheLookupArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            cache_key_additions=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_private_caching_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    response_policies=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesArgs(
                        header_transformations=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsArgs(
                            filter_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsFilterHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsFilterHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            ),
                            rename_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsRenameHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsRenameHeadersItemArgs(
                                    from_=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                            set_headers=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsSetHeadersArgs(
                                items=[oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesHeaderTransformationsSetHeadersItemArgs(
                                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    values=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                    if_exists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                                )],
                            ),
                        ),
                        response_cache_store=oci.api_gateway.DeploymentSpecificationRouteResponsePoliciesResponseCacheStoreArgs(
                            time_to_live_in_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                )],
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["deployment_display_name"],
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        Deployments can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:ApiGateway/deployment:Deployment test_deployment "id"
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 gateway_id: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[pulumi.InputType['DeploymentSpecificationArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentArgs.__new__(DeploymentArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            if gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_id'")
            __props__.__dict__["gateway_id"] = gateway_id
            if path_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'path_prefix'")
            __props__.__dict__["path_prefix"] = path_prefix
            if specification is None and not opts.urn:
                raise TypeError("Missing required property 'specification'")
            __props__.__dict__["specification"] = specification
            __props__.__dict__["endpoint"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(Deployment, __self__).__init__(
            'oci:ApiGateway/deployment:Deployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            endpoint: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            gateway_id: Optional[pulumi.Input[str]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            path_prefix: Optional[pulumi.Input[str]] = None,
            specification: Optional[pulumi.Input[pulumi.InputType['DeploymentSpecificationArgs']]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'Deployment':
        """
        Get an existing Deployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        :param pulumi.Input[str] endpoint: The endpoint to access this deployment on the gateway.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] gateway_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
        :param pulumi.Input[str] path_prefix: A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        :param pulumi.Input[pulumi.InputType['DeploymentSpecificationArgs']] specification: (Updatable) The logical configuration of the API exposed by a deployment.
        :param pulumi.Input[str] state: The current state of the deployment.
        :param pulumi.Input[str] time_created: The time this resource was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time this resource was last updated. An RFC3339 formatted datetime string.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentState.__new__(_DeploymentState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["path_prefix"] = path_prefix
        __props__.__dict__["specification"] = specification
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        return Deployment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.  Example: `My new resource`
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[str]:
        """
        The endpoint to access this deployment on the gateway.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> pulumi.Output[str]:
        """
        A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](https://docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
        """
        return pulumi.get(self, "path_prefix")

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Output['outputs.DeploymentSpecification']:
        """
        (Updatable) The logical configuration of the API exposed by a deployment.
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the deployment.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time this resource was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time this resource was last updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAuthTokensResult',
    'AwaitableGetAuthTokensResult',
    'get_auth_tokens',
    'get_auth_tokens_output',
]

@pulumi.output_type
class GetAuthTokensResult:
    """
    A collection of values returned by getAuthTokens.
    """
    def __init__(__self__, filters=None, id=None, tokens=None, user_id=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if tokens and not isinstance(tokens, list):
            raise TypeError("Expected argument 'tokens' to be a list")
        pulumi.set(__self__, "tokens", tokens)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAuthTokensFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tokens(self) -> Sequence['outputs.GetAuthTokensTokenResult']:
        """
        The list of tokens.
        """
        return pulumi.get(self, "tokens")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The OCID of the user the auth token belongs to.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetAuthTokensResult(GetAuthTokensResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthTokensResult(
            filters=self.filters,
            id=self.id,
            tokens=self.tokens,
            user_id=self.user_id)


def get_auth_tokens(filters: Optional[Sequence[pulumi.InputType['GetAuthTokensFilterArgs']]] = None,
                    user_id: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthTokensResult:
    """
    This data source provides the list of Auth Tokens in Oracle Cloud Infrastructure Identity service.

    Lists the auth tokens for the specified user. The returned object contains the token's OCID, but not
    the token itself. The actual token is returned only upon creation.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_auth_tokens = oci.Identity.get_auth_tokens(user_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str user_id: The OCID of the user.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getAuthTokens:getAuthTokens', __args__, opts=opts, typ=GetAuthTokensResult).value

    return AwaitableGetAuthTokensResult(
        filters=__ret__.filters,
        id=__ret__.id,
        tokens=__ret__.tokens,
        user_id=__ret__.user_id)


@_utilities.lift_output_func(get_auth_tokens)
def get_auth_tokens_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAuthTokensFilterArgs']]]]] = None,
                           user_id: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuthTokensResult]:
    """
    This data source provides the list of Auth Tokens in Oracle Cloud Infrastructure Identity service.

    Lists the auth tokens for the specified user. The returned object contains the token's OCID, but not
    the token itself. The actual token is returned only upon creation.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_auth_tokens = oci.Identity.get_auth_tokens(user_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str user_id: The OCID of the user.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['CaBundleArgs', 'CaBundle']

@pulumi.input_type
class CaBundleArgs:
    def __init__(__self__, *,
                 ca_bundle_pem: pulumi.Input[str],
                 compartment_id: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a CaBundle resource.
        :param pulumi.Input[str] ca_bundle_pem: (Updatable) Certificates (in PEM format) to include in the CA bundle.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment for the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) A brief description of the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] name: A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "ca_bundle_pem", ca_bundle_pem)
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="caBundlePem")
    def ca_bundle_pem(self) -> pulumi.Input[str]:
        """
        (Updatable) Certificates (in PEM format) to include in the CA bundle.
        """
        return pulumi.get(self, "ca_bundle_pem")

    @ca_bundle_pem.setter
    def ca_bundle_pem(self, value: pulumi.Input[str]):
        pulumi.set(self, "ca_bundle_pem", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The OCID of the compartment for the CA bundle.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A brief description of the CA bundle.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _CaBundleState:
    def __init__(__self__, *,
                 ca_bundle_pem: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CaBundle resources.
        :param pulumi.Input[str] ca_bundle_pem: (Updatable) Certificates (in PEM format) to include in the CA bundle.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment for the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) A brief description of the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] lifecycle_details: Additional information about the current lifecycle state of the CA bundle.
        :param pulumi.Input[str] name: A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current lifecycle state of the CA bundle.
        :param pulumi.Input[str] time_created: A property indicating when the CA bundle was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
        """
        if ca_bundle_pem is not None:
            pulumi.set(__self__, "ca_bundle_pem", ca_bundle_pem)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="caBundlePem")
    def ca_bundle_pem(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Certificates (in PEM format) to include in the CA bundle.
        """
        return pulumi.get(self, "ca_bundle_pem")

    @ca_bundle_pem.setter
    def ca_bundle_pem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ca_bundle_pem", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The OCID of the compartment for the CA bundle.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A brief description of the CA bundle.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        Additional information about the current lifecycle state of the CA bundle.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current lifecycle state of the CA bundle.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        A property indicating when the CA bundle was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class CaBundle(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_bundle_pem: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Ca Bundle resource in Oracle Cloud Infrastructure Certificates Management service.

        Creates a new CA bundle according to the details of the request.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_ca_bundle = oci.certificates_management.CaBundle("testCaBundle",
            ca_bundle_pem=var["ca_bundle_ca_bundle_pem"],
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            description=var["ca_bundle_description"],
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        CaBundles can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CertificatesManagement/caBundle:CaBundle test_ca_bundle "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ca_bundle_pem: (Updatable) Certificates (in PEM format) to include in the CA bundle.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment for the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) A brief description of the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] name: A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CaBundleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Ca Bundle resource in Oracle Cloud Infrastructure Certificates Management service.

        Creates a new CA bundle according to the details of the request.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_ca_bundle = oci.certificates_management.CaBundle("testCaBundle",
            ca_bundle_pem=var["ca_bundle_ca_bundle_pem"],
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            description=var["ca_bundle_description"],
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        CaBundles can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CertificatesManagement/caBundle:CaBundle test_ca_bundle "id"
        ```

        :param str resource_name: The name of the resource.
        :param CaBundleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CaBundleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_bundle_pem: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CaBundleArgs.__new__(CaBundleArgs)

            if ca_bundle_pem is None and not opts.urn:
                raise TypeError("Missing required property 'ca_bundle_pem'")
            __props__.__dict__["ca_bundle_pem"] = ca_bundle_pem
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["description"] = description
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["name"] = name
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
        super(CaBundle, __self__).__init__(
            'oci:CertificatesManagement/caBundle:CaBundle',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ca_bundle_pem: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'CaBundle':
        """
        Get an existing CaBundle resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ca_bundle_pem: (Updatable) Certificates (in PEM format) to include in the CA bundle.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment for the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) A brief description of the CA bundle.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] lifecycle_details: Additional information about the current lifecycle state of the CA bundle.
        :param pulumi.Input[str] name: A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current lifecycle state of the CA bundle.
        :param pulumi.Input[str] time_created: A property indicating when the CA bundle was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CaBundleState.__new__(_CaBundleState)

        __props__.__dict__["ca_bundle_pem"] = ca_bundle_pem
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["name"] = name
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        return CaBundle(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="caBundlePem")
    def ca_bundle_pem(self) -> pulumi.Output[str]:
        """
        (Updatable) Certificates (in PEM format) to include in the CA bundle.
        """
        return pulumi.get(self, "ca_bundle_pem")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The OCID of the compartment for the CA bundle.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) A brief description of the CA bundle.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        Additional information about the current lifecycle state of the CA bundle.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current lifecycle state of the CA bundle.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        A property indicating when the CA bundle was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

